@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2015 Laurent Montel <montel@kde.org>
+    Copyright (c) 2013-2017 Laurent Montel <montel@kde.org>
 
     Copyright (c) 2010 Volker Krause <vkrause@kde.org>
 
@@ -58,9 +58,9 @@ using namespace Akonadi;
 
 NewMailNotifierAgent::NewMailNotifierAgent(const QString &id)
     : AgentBase(id)
-    #ifdef HAVE_TEXTTOSPEECH
-    , mTextToSpeech(Q_NULLPTR)
-    #endif
+#ifdef HAVE_TEXTTOSPEECH
+    , mTextToSpeech(nullptr)
+#endif
 {
     Kdelibs4ConfigMigrator migrate(QStringLiteral("newmailnotifieragent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_newmailnotifier_agentrc") << QStringLiteral("akonadi_newmailnotifier_agent.notifyrc"));
@@ -291,9 +291,9 @@ void NewMailNotifierAgent::itemsRemoved(const Item::List &items)
     for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it) {
         QList<Akonadi::Item::Id> idList = it.value();
         bool itemFound = false;
-        Q_FOREACH (const Item &item, items) {
-            if (idList.contains(item.id())) {
-                idList.removeAll(item.id());
+        for (const Item &item : items) {
+            const int numberOfItemsRemoved = idList.removeAll(item.id());
+            if (numberOfItemsRemoved > 0) {
                 itemFound = true;
             }
         }
@@ -314,7 +314,7 @@ void NewMailNotifierAgent::itemsFlagsChanged(const Akonadi::Item::List &items, c
     if (!isActive()) {
         return;
     }
-    Q_FOREACH (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator end(mNewMails.end());
         for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::iterator it = mNewMails.begin(); it != end; ++it) {
             QList<Akonadi::Item::Id> idList = it.value();
@@ -337,7 +337,7 @@ void NewMailNotifierAgent::itemsMoved(const Akonadi::Item::List &items, const Ak
         return;
     }
 
-    Q_FOREACH (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         if (ignoreStatusMail(item)) {
             continue;
         }
@@ -348,9 +348,8 @@ void NewMailNotifierAgent::itemsMoved(const Akonadi::Item::List &items, const Ak
 
         if (mNewMails.contains(collectionSource)) {
             QList<Akonadi::Item::Id> idListFrom = mNewMails[ collectionSource ];
-            if (idListFrom.contains(item.id())) {
-                idListFrom.removeAll(item.id());
-
+            const int removeItems = idListFrom.removeAll(item.id());
+            if (removeItems > 0) {
                 if (idListFrom.isEmpty()) {
                     mNewMails.remove(collectionSource);
                 } else {
@@ -418,12 +417,12 @@ void NewMailNotifierAgent::slotShowNotifications()
         Akonadi::Item::Id item = -1;
         QString currentPath;
         QStringList texts;
-        QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator end(mNewMails.constEnd());
         const int numberOfCollection(mNewMails.count());
         if (numberOfCollection > 1) {
             hasUniqMessage = false;
         }
 
+        QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator end(mNewMails.constEnd());
         for (QHash< Akonadi::Collection, QList<Akonadi::Item::Id> >::const_iterator it = mNewMails.constBegin(); it != end; ++it) {
             Akonadi::EntityDisplayAttribute *attr = it.key().attribute<Akonadi::EntityDisplayAttribute>();
             QString displayName;
@@ -448,7 +447,8 @@ void NewMailNotifierAgent::slotShowNotifications()
             }
             QString resourceName;
             if (!mCacheResourceName.contains(it.key().resource())) {
-                Q_FOREACH (const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances()) {
+                const Akonadi::AgentInstance::List lst = Akonadi::AgentManager::self()->instances();
+                for (const Akonadi::AgentInstance &instance : lst) {
                     if (instance.identifier() == it.key().resource()) {
                         mCacheResourceName.insert(instance.identifier(), instance.name());
                         resourceName = instance.name();
@@ -494,7 +494,7 @@ void NewMailNotifierAgent::slotDisplayNotification(const QPixmap &pixmap, const
     KNotification::event(QStringLiteral("new-email"),
                          message,
                          pixmap,
-                         Q_NULLPTR,
+                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_newmailnotifier_agent"));
 
@@ -507,8 +507,8 @@ void NewMailNotifierAgent::slotInstanceNameChanged(const Akonadi::AgentInstance
     }
 
     const QString identifier(instance.identifier());
-    if (mCacheResourceName.contains(identifier)) {
-        mCacheResourceName.remove(identifier);
+    int resourceNameRemoved = mCacheResourceName.remove(identifier);
+    if (resourceNameRemoved > 0) {
         mCacheResourceName.insert(identifier, instance.name());
     }
 }
@@ -523,9 +523,7 @@ void NewMailNotifierAgent::slotInstanceStatusChanged(const Akonadi::AgentInstanc
     switch (instance.status()) {
     case Akonadi::AgentInstance::Broken:
     case Akonadi::AgentInstance::Idle: {
-        if (mInstanceNameInProgress.contains(identifier)) {
-            mInstanceNameInProgress.removeAll(identifier);
-        }
+        mInstanceNameInProgress.removeAll(identifier);
         break;
     }
     case Akonadi::AgentInstance::Running: {
@@ -564,9 +562,7 @@ void NewMailNotifierAgent::slotInstanceRemoved(const Akonadi::AgentInstance &ins
     }
 
     const QString identifier(instance.identifier());
-    if (mInstanceNameInProgress.contains(identifier)) {
-        mInstanceNameInProgress.removeAll(identifier);
-    }
+    mInstanceNameInProgress.removeAll(identifier);
 }
 
 void NewMailNotifierAgent::slotInstanceAdded(const Akonadi::AgentInstance &instance)
