@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,6 +35,22 @@
 #include "newmailnotifier_debug.h"
 
 #include <QTextDocument>
+#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
+namespace QtPrivate
+{
+template <typename T> struct QAddConst {
+    typedef const T Type;
+};
+}
+
+// this adds const to non-const objects (like std::as_const)
+template <typename T>
+Q_DECL_CONSTEXPR typename QtPrivate::QAddConst<T>::Type &qAsConst(T &t) Q_DECL_NOTHROW { return t; }
+// prevent rvalue arguments:
+template <typename T>
+void qAsConst(const T &&) Q_DECL_EQ_DELETE;
+#endif
+
 
 SpecialNotifierJob::SpecialNotifierJob(const QStringList &listEmails, const QString &path, Akonadi::Item::Id id, QObject *parent)
     : QObject(parent),
@@ -120,7 +136,7 @@ void SpecialNotifierJob::slotSearchJobFinished(KJob *job)
 void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
 {
     if (NewMailNotifierAgentSettings::excludeEmailsFromMe()) {
-        Q_FOREACH (const QString &email, mListEmails) {
+        for (const QString &email : qAsConst(mListEmails)) {
             if (mFrom.contains(email)) {
                 //Exclude this notification
                 deleteLater();
@@ -155,8 +171,8 @@ void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
     }
 
     if (NewMailNotifierAgentSettings::showButtonToDisplayMail()) {
-        KNotification *notification = new KNotification(QStringLiteral("new-email"), Q_NULLPTR, KNotification::CloseOnTimeout);
-        notification->setText(result.join(QStringLiteral("\n")));
+        KNotification *notification = new KNotification(QStringLiteral("new-email"), nullptr, KNotification::CloseOnTimeout);
+        notification->setText(result.join(QLatin1Char('\n')));
         notification->setPixmap(pixmap);
         notification->setActions(QStringList() << i18n("Show mail..."));
 
@@ -165,7 +181,7 @@ void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
 
         notification->sendEvent();
     } else {
-        Q_EMIT displayNotification(pixmap, result.join(QStringLiteral("\n")));
+        Q_EMIT displayNotification(pixmap, result.join(QLatin1Char('\n')));
         deleteLater();
     }
 }
