@@ -22,17 +22,17 @@
 #include "settings.h"
 
 #include "settingsadaptor.h"
-#ifdef HAVE_ACCOUNTS
-#include "../../shared/singlefileresource/getcredentialsjob.h"
-#endif
+#include "utils.h"
+#include "davresource_debug.h"
 
 #include <kapplication.h>
-#include "davresource_debug.h"
 #include <klineedit.h>
 #include <KLocalizedString>
 
 #include <kwallet.h>
 
+#include <KDAV/Utils>
+
 #include <QtCore/QByteArray>
 #include <QtCore/QDataStream>
 #include <QtCore/QFile>
@@ -48,17 +48,11 @@
 #include <QDialog>
 #include <QPushButton>
 
-#ifdef HAVE_ACCOUNTS
-#include <Accounts/Account>
-#include <Accounts/Manager>
-#include <QStandardPaths>
-#endif
-
 class SettingsHelper
 {
 public:
     SettingsHelper()
-        : q(Q_NULLPTR)
+        : q(nullptr)
     {
     }
 
@@ -82,7 +76,7 @@ Settings::UrlConfiguration::UrlConfiguration(const QString &serialized)
 
     if (splitString.size() == 3) {
         mUrl = splitString.at(2);
-        mProtocol = DavUtils::protocolByName(splitString.at(1));
+        mProtocol = KDAV::Utils::protocolByName(splitString.at(1));
         mUser = splitString.at(0);
     }
 }
@@ -90,7 +84,7 @@ Settings::UrlConfiguration::UrlConfiguration(const QString &serialized)
 QString Settings::UrlConfiguration::serialize()
 {
     QString serialized = mUser;
-    serialized.append(QLatin1Char('|')).append(DavUtils::protocolName(DavUtils::Protocol(mProtocol)));
+    serialized.append(QLatin1Char('|')).append(KDAV::Utils::protocolName(KDAV::Protocol(mProtocol)));
     serialized.append(QLatin1Char('|')).append(mUrl);
     return serialized;
 }
@@ -109,9 +103,6 @@ Settings::Settings()
     : SettingsBase(), mWinId(0)
 {
 
-#ifdef HAVE_ACCOUNTS
-    m_manager = 0;
-#endif
     Q_ASSERT(!s_globalSettings->q);
     s_globalSettings->q = this;
 
@@ -172,25 +163,24 @@ QString Settings::defaultPassword()
     return loadPassword(mResourceIdentifier, QStringLiteral("$default$"));
 }
 
-DavUtils::DavUrl::List Settings::configuredDavUrls()
+KDAV::DavUrl::List Settings::configuredDavUrls()
 {
     if (mUrls.isEmpty()) {
         buildUrlsList();
     }
-    DavUtils::DavUrl::List davUrls;
+    KDAV::DavUrl::List davUrls;
     davUrls.reserve(mUrls.count());
-    QMapIterator<QString, UrlConfiguration *> it(mUrls);
-
-    while (it.hasNext()) {
-        it.next();
+    QMap<QString, UrlConfiguration *>::const_iterator it = mUrls.cbegin();
+    const QMap<QString, UrlConfiguration *>::const_iterator itEnd = mUrls.cend();
+    for (; it != itEnd; ++it) {
         QStringList split = it.key().split(QLatin1Char(','));
-        davUrls << configuredDavUrl(DavUtils::protocolByName(split.at(1)), split.at(0));
+        davUrls << configuredDavUrl(KDAV::Utils::protocolByName(split.at(1)), split.at(0));
     }
 
     return davUrls;
 }
 
-DavUtils::DavUrl Settings::configuredDavUrl(DavUtils::Protocol proto, const QString &searchUrl, const QString &finalUrl)
+KDAV::DavUrl Settings::configuredDavUrl(KDAV::Protocol proto, const QString &searchUrl, const QString &finalUrl)
 {
     if (mUrls.isEmpty()) {
         buildUrlsList();
@@ -208,35 +198,35 @@ DavUtils::DavUrl Settings::configuredDavUrl(DavUtils::Protocol proto, const QStr
     fullUrl.setUserName(user);
     fullUrl.setPassword(password(proto, searchUrl));
 
-    return DavUtils::DavUrl(fullUrl, proto);
+    return KDAV::DavUrl(fullUrl, proto);
 }
 
-DavUtils::DavUrl Settings::davUrlFromCollectionUrl(const QString &collectionUrl, const QString &finalUrl)
+KDAV::DavUrl Settings::davUrlFromCollectionUrl(const QString &collectionUrl, const QString &finalUrl)
 {
     if (mCollectionsUrlsMapping.isEmpty()) {
         loadMappings();
     }
 
-    DavUtils::DavUrl davUrl;
+    KDAV::DavUrl davUrl;
     QString targetUrl = finalUrl.isEmpty() ? collectionUrl : finalUrl;
 
     if (mCollectionsUrlsMapping.contains(collectionUrl)) {
         QStringList split = mCollectionsUrlsMapping[ collectionUrl ].split(QLatin1Char(','));
         if (split.size() == 2) {
-            davUrl = configuredDavUrl(DavUtils::protocolByName(split.at(1)), split.at(0), targetUrl);
+            davUrl = configuredDavUrl(KDAV::Utils::protocolByName(split.at(1)), split.at(0), targetUrl);
         }
     }
 
     return davUrl;
 }
 
-void Settings::addCollectionUrlMapping(DavUtils::Protocol proto, const QString &collectionUrl, const QString &configuredUrl)
+void Settings::addCollectionUrlMapping(KDAV::Protocol proto, const QString &collectionUrl, const QString &configuredUrl)
 {
     if (mCollectionsUrlsMapping.isEmpty()) {
         loadMappings();
     }
 
-    QString value = configuredUrl + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString value = configuredUrl + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
     mCollectionsUrlsMapping.insert(collectionUrl, value);
 
     // Update the cache now
@@ -255,21 +245,18 @@ void Settings::addCollectionUrlMapping(DavUtils::Protocol proto, const QString &
     }
 }
 
-QStringList Settings::mappedCollections(DavUtils::Protocol proto, const QString &configuredUrl)
+QStringList Settings::mappedCollections(KDAV::Protocol proto, const QString &configuredUrl)
 {
     if (mCollectionsUrlsMapping.isEmpty()) {
         loadMappings();
     }
 
-    QString value = configuredUrl + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString value = configuredUrl + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
     return mCollectionsUrlsMapping.keys(value);
 }
 
 void Settings::reloadConfig()
 {
-#ifdef HAVE_ACCOUNTS
-    importFromAccounts();
-#endif
     buildUrlsList();
     updateRemoteUrls();
     loadMappings();
@@ -277,10 +264,10 @@ void Settings::reloadConfig()
 
 void Settings::newUrlConfiguration(Settings::UrlConfiguration *urlConfig)
 {
-    QString key = urlConfig->mUrl + QLatin1Char(',') + DavUtils::protocolName(DavUtils::Protocol(urlConfig->mProtocol));
+    QString key = urlConfig->mUrl + QLatin1Char(',') + KDAV::Utils::protocolName(KDAV::Protocol(urlConfig->mProtocol));
 
     if (mUrls.contains(key)) {
-        removeUrlConfiguration(DavUtils::Protocol(urlConfig->mProtocol), urlConfig->mUrl);
+        removeUrlConfiguration(KDAV::Protocol(urlConfig->mProtocol), urlConfig->mUrl);
     }
 
     mUrls[ key ] = urlConfig;
@@ -290,9 +277,9 @@ void Settings::newUrlConfiguration(Settings::UrlConfiguration *urlConfig)
     updateRemoteUrls();
 }
 
-void Settings::removeUrlConfiguration(DavUtils::Protocol proto, const QString &url)
+void Settings::removeUrlConfiguration(KDAV::Protocol proto, const QString &url)
 {
-    QString key = url + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString key = url + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
 
     if (!mUrls.contains(key)) {
         return;
@@ -303,11 +290,11 @@ void Settings::removeUrlConfiguration(DavUtils::Protocol proto, const QString &u
     updateRemoteUrls();
 }
 
-Settings::UrlConfiguration *Settings::urlConfiguration(DavUtils::Protocol proto, const QString &url)
+Settings::UrlConfiguration *Settings::urlConfiguration(KDAV::Protocol proto, const QString &url)
 {
-    QString key = url + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString key = url + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
 
-    UrlConfiguration *ret = Q_NULLPTR;
+    UrlConfiguration *ret = nullptr;
     if (mUrls.contains(key)) {
         ret = mUrls[ key ];
     }
@@ -315,46 +302,40 @@ Settings::UrlConfiguration *Settings::urlConfiguration(DavUtils::Protocol proto,
     return ret;
 }
 
-// DavUtils::Protocol Settings::protocol( const QString &url ) const
+// KDAV::Protocol Settings::protocol( const QString &url ) const
 // {
 //   if ( mUrls.contains( url ) )
-//     return DavUtils::Protocol( mUrls[ url ]->mProtocol );
+//     return KDAV::Protocol( mUrls[ url ]->mProtocol );
 //   else
-//     return DavUtils::CalDav;
+//     returnKDAV::CalDav;
 // }
 
-QString Settings::username(DavUtils::Protocol proto, const QString &url) const
+QString Settings::username(KDAV::Protocol proto, const QString &url) const
 {
-    QString key = url + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString key = url + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
 
-    if (mUrls.contains(key))
+    if (mUrls.contains(key)) {
         if (mUrls[ key ]->mUser == QLatin1String("$default$")) {
             return defaultUsername();
-        }
-#ifdef HAVE_ACCOUNTS
-        else if (mUrls[ key ]->mUser == QLatin1String("$accounts$")) {
-            return accountsUsername();
-        }
-#endif
-        else {
+        } else {
             return mUrls[ key ]->mUser;
         }
-    else {
+    } else {
         return QString();
     }
 }
 
-QString Settings::password(DavUtils::Protocol proto, const QString &url)
+QString Settings::password(KDAV::Protocol proto, const QString &url)
 {
-    QString key = url + QLatin1Char(',') + DavUtils::protocolName(proto);
+    QString key = url + QLatin1Char(',') + KDAV::Utils::protocolName(proto);
 
-    if (mUrls.contains(key))
+    if (mUrls.contains(key)) {
         if (mUrls[ key ]->mUser == QLatin1String("$default$")) {
             return defaultPassword();
         } else {
             return mUrls[ key ]->mPassword;
         }
-    else {
+    } else {
         return QString();
     }
 }
@@ -378,104 +359,11 @@ QDateTime Settings::getSyncRangeStart() const
     return start;
 }
 
-#ifdef HAVE_ACCOUNTS
-void Settings::importFromAccounts()
-{
-    qCDebug(DAVRESOURCE_LOG);
-    Accounts::AccountId id = accountId();
-    qCDebug(DAVRESOURCE_LOG) << "Account Id: " << id;
-
-    if (!m_manager) {
-        m_manager = new Accounts::Manager(this);
-    }
-
-    if (!m_manager->accountList().contains(id)) {
-        return;
-    }
-
-    removeAccountsDisabledServices();
-    addAccountsEnabledServices();
-
-    setSettingsVersion(3);
-    writeConfig();
-}
-
-void Settings::addAccountsEnabledServices()
-{
-    qCDebug(DAVRESOURCE_LOG);
-    Accounts::Account *acc = m_manager->account(accountId());
-    QStringList enabledServices = accountServices();
-    qCDebug(DAVRESOURCE_LOG) << "Enabled" << enabledServices;
-    foreach (QString serviceType, enabledServices) {
-        Accounts::ServiceList services = acc->services(serviceType);
-        foreach (const Accounts::Service &service, services) {
-            configureAccountService(acc, service);
-        }
-    }
-}
-
-void Settings::removeAccountsDisabledServices()
-{
-    qCDebug(DAVRESOURCE_LOG);
-    QStringList urls = remoteUrls();
-    for (int i = 0; i < urls.size(); ++i) {
-        if (!urls.at(i).startsWith(QStringLiteral("$accounts$"))) {
-            continue;
-        }
-
-        if (urls.at(i).contains(QStringLiteral("carddav"))
-                && accountServices().contains(QStringLiteral("dav-contacts"))) {
-            continue;
-        }
-        if (urls.at(i).contains(QStringLiteral("caldav"))
-                && accountServices().contains(QStringLiteral("dav-calendar"))) {
-            continue;
-        }
-
-        urls.removeAt(i);
-    }
-
-    setRemoteUrls(urls);
-}
-
-void Settings::configureAccountService(Accounts::Account *acc, const Accounts::Service &service)
-{
-    qCDebug(DAVRESOURCE_LOG) << "Configuring service: " << service.name();
-
-    acc->selectService();
-    QString domain = acc->valueAsString(QStringLiteral("dav/scheme")) + QStringLiteral("://") + acc->valueAsString(QStringLiteral("dav/host"));
-    acc->selectService(service);
-
-    QString type;
-    if (service.serviceType() == QLatin1String("dav-contacts")) {
-        type = QStringLiteral("CardDav");
-    } else {
-        type = QStringLiteral("CalDav");
-    }
-
-    QString url = QStringLiteral("$accounts$|") + type + QLatin1Char('|') + domain + acc->valueAsString(QStringLiteral("dav/path"));
-    qCDebug(DAVRESOURCE_LOG) << url;
-    acc->selectService();
-
-    QStringList urls = remoteUrls();
-    foreach (const QString &serializedUrl, urls) {
-        if (url == serializedUrl) {
-            qCDebug(DAVRESOURCE_LOG) << "Url already configured";
-            return;
-        }
-    }
-
-    qCDebug(DAVRESOURCE_LOG) << "Adding url";
-    urls.append(url);
-    setRemoteUrls(urls);
-}
-#endif
-
 void Settings::buildUrlsList()
 {
     foreach (const QString &serializedUrl, remoteUrls()) {
         UrlConfiguration *urlConfig = new UrlConfiguration(serializedUrl);
-        QString key = urlConfig->mUrl + QLatin1Char(',') + DavUtils::protocolName(DavUtils::Protocol(urlConfig->mProtocol));
+        QString key = urlConfig->mUrl + QLatin1Char(',') + KDAV::Utils::protocolName(KDAV::Protocol(urlConfig->mProtocol));
         QString pass = loadPassword(key, urlConfig->mUser);
         if (!pass.isNull()) {
             urlConfig->mPassword = pass;
@@ -549,11 +437,6 @@ QString Settings::loadPassword(const QString &key, const QString &user)
     if (user == QLatin1String("$default$")) {
         entry = mResourceIdentifier + QLatin1Char(',') + user;
     }
-#ifdef HAVE_ACCOUNTS
-    else if (user == QLatin1String("$accounts$")) {
-        return loadPasswordFromAccounts();
-    }
-#endif
     else {
         entry = key + QLatin1Char(',') + user;
     }
@@ -589,28 +472,6 @@ QString Settings::loadPassword(const QString &key, const QString &user)
     return pass;
 }
 
-#ifdef HAVE_ACCOUNTS
-QString Settings::loadPasswordFromAccounts()
-{
-    qCDebug(DAVRESOURCE_LOG) << "Getting credentials for: " << accountId();
-    GetCredentialsJob *job = new GetCredentialsJob(accountId());
-    job->exec();
-
-    return job->credentialsData().value(QLatin1String("Secret")).toString();
-}
-
-QString Settings::accountsUsername() const
-{
-    qCDebug(DAVRESOURCE_LOG) << "Getting credentials for: " << accountId();
-    GetCredentialsJob *job = new GetCredentialsJob(accountId());
-    job->exec();
-
-    qCDebug(DAVRESOURCE_LOG) << "Got some: " << job->credentialsData();
-
-    return job->credentialsData().value(QLatin1String("UserName")).toString();
-}
-#endif
-
 QString Settings::promptForPassword(const QString &user)
 {
     QPointer<QDialog> dlg = new QDialog();
@@ -675,7 +536,7 @@ void Settings::updateToV2()
     }
 
     setDefaultUsername(urlConfig.mUser);
-    QString key = urlConfig.mUrl + QLatin1Char(',') + DavUtils::protocolName(DavUtils::Protocol(urlConfig.mProtocol));
+    QString key = urlConfig.mUrl + QLatin1Char(',') + KDAV::Utils::protocolName(KDAV::Protocol(urlConfig.mProtocol));
     QString pass = loadPassword(key, urlConfig.mUser);
     if (!pass.isNull()) {
         setDefaultPassword(pass);
@@ -693,9 +554,9 @@ void Settings::updateToV3()
         QStringList splitUrl = url.split(QLatin1Char('|'));
 
         if (splitUrl.size() == 3) {
-            DavUtils::Protocol protocol = DavUtils::protocolByTranslatedName(splitUrl.at(1));
-            splitUrl[1] = DavUtils::protocolName(protocol);
-            updatedUrls << splitUrl.join(QStringLiteral("|"));
+            KDAV::Protocol protocol = Utils::protocolByTranslatedName(splitUrl.at(1));
+            splitUrl[1] = KDAV::Utils::protocolName(protocol);
+            updatedUrls << splitUrl.join(QLatin1Char('|'));
         }
     }
 
