@@ -34,7 +34,7 @@ class AddCollectionTask : public ResourceTask
     Q_OBJECT
 
 public:
-    explicit AddCollectionTask(const ResourceStateInterface::Ptr &resource, QObject *parent = Q_NULLPTR);
+    explicit AddCollectionTask(const ResourceStateInterface::Ptr &resource, QObject *parent = nullptr);
     virtual ~AddCollectionTask();
 
 protected:
