@@ -24,6 +24,7 @@
 */
 
 #include "imapresourcebase.h"
+#include "helper_p.h"
 
 #include <QHostInfo>
 #include <QSettings>
@@ -97,9 +98,9 @@ using namespace Akonadi;
 ImapResourceBase::ImapResourceBase(const QString &id)
     : ResourceBase(id),
       m_pool(new SessionPool(2, this)),
-      m_settings(Q_NULLPTR),
-      mSubscriptions(Q_NULLPTR),
-      m_idle(Q_NULLPTR)
+      m_settings(nullptr),
+      mSubscriptions(nullptr),
+      m_idle(nullptr)
 {
     QTimer::singleShot(0, this, &ImapResourceBase::updateResourceName);
 
@@ -170,12 +171,10 @@ ImapResourceBase::~ImapResourceBase()
 {
     //Destroy everything that could cause callbacks immediately, otherwise the callbacks can result in a crash.
 
-    if (m_idle) {
-        delete m_idle;
-        m_idle = Q_NULLPTR;
-    }
+    delete m_idle;
+    m_idle = nullptr;
 
-    Q_FOREACH (ResourceTask *task, m_taskList) {
+    for (ResourceTask *task : qAsConst(m_taskList)) {
         delete task;
     }
     m_taskList.clear();
@@ -191,7 +190,7 @@ void ImapResourceBase::aboutToQuit()
         m_idle->stop();
     }
 
-    Q_FOREACH (ResourceTask *task, m_taskList) {
+    for (ResourceTask *task : qAsConst(m_taskList)) {
         task->kill();
     }
 
@@ -263,7 +262,7 @@ int ImapResourceBase::configureSubscription(qlonglong windowId)
         return -1;
     }
 
-    mSubscriptions = new SubscriptionDialog(Q_NULLPTR, SubscriptionDialog::AllowToEnableSubscription);
+    mSubscriptions = new SubscriptionDialog(nullptr, SubscriptionDialog::AllowToEnableSubscription);
     if (windowId) {
 #ifndef Q_OS_WIN
         KWindowSystem::setMainWindow(mSubscriptions, windowId);
@@ -341,7 +340,7 @@ ResourceStateInterface::Ptr ImapResourceBase::createResourceState(const TaskArgu
 
 Settings *ImapResourceBase::settings() const
 {
-    if (m_settings == Q_NULLPTR) {
+    if (m_settings == nullptr) {
         m_settings = new Settings;
     }
 
@@ -507,8 +506,6 @@ void ImapResourceBase::doSearch(const QVariant &arg)
     startTask(new SearchTask(createResourceState(TaskArguments(collection)), query, this));
 }
 
-// -----
-
 // ----------------------------------------------------------------------------------
 
 void ImapResourceBase::scheduleConnectionAttempt()
@@ -521,7 +518,7 @@ void ImapResourceBase::doSetOnline(bool online)
 {
     qCDebug(IMAPRESOURCE_LOG) << "online=" << online;
     if (!online) {
-        Q_FOREACH (ResourceTask *task, m_taskList) {
+        for (ResourceTask *task : qAsConst(m_taskList)) {
             task->kill();
             delete task;
         }
@@ -533,7 +530,7 @@ void ImapResourceBase::doSetOnline(bool online)
         if (m_idle) {
             m_idle->stop();
             delete m_idle;
-            m_idle = Q_NULLPTR;
+            m_idle = nullptr;
         }
         settings()->clearCachedPassword();
     } else if (online && !m_pool->isConnected()) {
@@ -583,7 +580,7 @@ void ImapResourceBase::startIdleIfNeeded()
 void ImapResourceBase::startIdle()
 {
     delete m_idle;
-    m_idle = Q_NULLPTR;
+    m_idle = nullptr;
 
     if (!m_pool->serverCapabilities().contains(QStringLiteral("IDLE"))) {
         return;
@@ -725,7 +722,7 @@ void ImapResourceBase::cleanup()
 QString ImapResourceBase::dumpResourceToString() const
 {
     QString ret;
-    Q_FOREACH (ResourceTask *task, m_taskList) {
+    for (ResourceTask *task : qAsConst(m_taskList)) {
         if (!ret.isEmpty()) {
             ret += QLatin1String(", ");
         }
