@@ -34,7 +34,7 @@
 #include "imapresource_debug.h"
 #include <KLocalizedString>
 
-RetrieveCollectionsTask::RetrieveCollectionsTask(ResourceStateInterface::Ptr resource, QObject *parent)
+RetrieveCollectionsTask::RetrieveCollectionsTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
     : ResourceTask(CancelIfNoSession, resource, parent)
 {
 }
@@ -101,8 +101,7 @@ void RetrieveCollectionsTask::doStart(KIMAP::Session *session)
 void RetrieveCollectionsTask::onMailBoxesReceived(const QList< KIMAP::MailBoxDescriptor > &descriptors,
         const QList< QList<QByteArray> > &flags)
 {
-    QStringList contentTypes;
-    contentTypes << KMime::Message::mimeType() << Akonadi::Collection::mimeType();
+    const QStringList contentTypes = { KMime::Message::mimeType(), Akonadi::Collection::mimeType()};
 
     if (!descriptors.isEmpty()) {
         // This is still not optimal way of getting the separator, but it's better
@@ -222,7 +221,7 @@ void RetrieveCollectionsTask::onFullMailBoxesReceived(const QList< KIMAP::MailBo
         const QList< QList< QByteArray > > &flags)
 {
     Q_UNUSED(flags);
-    foreach (const KIMAP::MailBoxDescriptor &descriptor, descriptors) {
+    for (const KIMAP::MailBoxDescriptor &descriptor : descriptors) {
         m_fullReportedCollections.insert(descriptor.name);
     }
 }
