@@ -26,7 +26,7 @@
 #include <SearchQuery>
 #include <Akonadi/KMime/MessageFlags>
 #include "imapresource_debug.h"
-
+#include <KLocalizedString>
 Q_DECLARE_METATYPE(KIMAP::Session *)
 
 SearchTask::SearchTask(const ResourceStateInterface::Ptr &state,  const QString &query, QObject *parent)
@@ -79,7 +79,8 @@ static KIMAP::Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
         QVector<KIMAP::Term> subterms;
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+        const QList<Akonadi::SearchTerm> lstSearchTermsList = term.subTerms();
+        for (const Akonadi::SearchTerm &subterm : lstSearchTermsList) {
             const KIMAP::Term newTerm = recursiveEmailTermMapping(subterm);
             if (!newTerm.isNull()) {
                 subterms << newTerm;
@@ -195,7 +196,7 @@ void SearchTask::doSearch(KIMAP::Session *session)
     if (term.isNull()) {
         qCWarning(IMAPRESOURCE_LOG) << "failed to translate query " << m_query;
         searchFinished(QVector<qint64>());
-        cancelTask(QStringLiteral("Invalid search"));
+        cancelTask(i18n("Invalid search"));
         return;
     }
     searchJob->setTerm(term);
