@@ -100,9 +100,10 @@ private:
 
 private Q_SLOTS:
     void slotTest();
-    void slotFinished(const QList<int> &testResult);
+    void slotFinished(const QVector<int> &testResult);
     void slotCustomSieveChanged();
 
+    void slotServerChanged();
     void slotTestChanged();
     void slotComplete();
     void slotSafetyChanged();
