@@ -49,7 +49,7 @@ class CompactChangeHelper::Private
     CompactChangeHelper *const q;
 
 public:
-    explicit Private(CompactChangeHelper *parent) : q(parent), mSession(Q_NULLPTR)
+    explicit Private(CompactChangeHelper *parent) : q(parent), mSession(nullptr)
     {
     }
 
@@ -100,7 +100,7 @@ void CompactChangeHelper::Private::processNextItem()
 void CompactChangeHelper::Private::itemFetchResult(KJob *job)
 {
     ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
-    Q_ASSERT(fetchJob != 0);
+    Q_ASSERT(fetchJob != nullptr);
 
     const QString oldRemoteId = fetchJob->property("oldRemoteId").toString();
     Q_ASSERT(!oldRemoteId.isEmpty());
@@ -152,7 +152,7 @@ void CompactChangeHelper::addChangedItems(const Item::List &items)
                                       << "pendingUpdates.count=" << d->mPendingUpdates.count();
     UpdateBatch updateBatch;
 
-    Q_FOREACH (const Item &item, items) {
+    for (const Item &item : items) {
         const Collection collection = item.parentCollection();
         const qint64 revision = collection.remoteRevision().toLongLong();
 
