@@ -20,6 +20,7 @@
 #include "accountdialog.h"
 #include "settings.h"
 #include "jobs.h"
+#include "helper_p.h"
 #include <AkonadiCore/Pop3ResourceAttribute>
 
 #include <CollectionFetchJob>
@@ -48,13 +49,13 @@ using namespace KWallet;
 POP3Resource::POP3Resource(const QString &id)
     : ResourceBase(id),
       mState(Idle),
-      mPopSession(Q_NULLPTR),
+      mPopSession(nullptr),
       mAskAgain(false),
       mIntervalTimer(new QTimer(this)),
       mTestLocalInbox(false),
-      mWallet(Q_NULLPTR),
+      mWallet(nullptr),
       mIdsToSaveValid(false),
-      mDeleteJob(Q_NULLPTR)
+      mDeleteJob(nullptr)
 {
     Akonadi::AttributeFactory::registerAttribute<Akonadi::Pop3ResourceAttribute>();
     setNeedsNetwork(true);
@@ -71,7 +72,7 @@ POP3Resource::~POP3Resource()
 {
     Settings::self()->save();
     delete mWallet;
-    mWallet = Q_NULLPTR;
+    mWallet = nullptr;
 }
 
 void POP3Resource::configurationChanged()
@@ -145,7 +146,7 @@ bool POP3Resource::retrieveItem(const Akonadi::Item &item, const QSet<QByteArray
 QString POP3Resource::buildLabelForPasswordDialog(const QString &detailedError) const
 {
     const QString queryText = i18n("Please enter the username and password for account '%1'.",
-                             agentName()) + QLatin1String("<br>") + detailedError;
+                                   agentName()) + QLatin1String("<br>") + detailedError;
     return queryText;
 }
 
@@ -165,11 +166,11 @@ void POP3Resource::walletOpenedForLoading(bool success)
         }
     }
     delete mWallet;
-    mWallet = Q_NULLPTR;
+    mWallet = nullptr;
 
     if (!passwordLoaded) {
         const QString queryText = buildLabelForPasswordDialog(
-                                i18n("You are asked here because the password could not be loaded from the wallet."));
+                                      i18n("You are asked here because the password could not be loaded from the wallet."));
         showPasswordDialog(queryText);
     } else {
         advanceState(Connect);
@@ -191,7 +192,7 @@ void POP3Resource::walletOpenedForSaving(bool success)
     }
 
     delete mWallet;
-    mWallet = Q_NULLPTR;
+    mWallet = nullptr;
     finish();
 }
 
@@ -199,7 +200,7 @@ void POP3Resource::showPasswordDialog(const QString &queryText)
 {
     QPointer<KPasswordDialog> dlg =
         new KPasswordDialog(
-        Q_NULLPTR,
+        nullptr,
         KPasswordDialog::ShowUsernameLine);
     dlg->setModal(true);
     dlg->setUsername(Settings::self()->login());
@@ -245,17 +246,17 @@ void POP3Resource::doStateStep()
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state FetchTargetCollection ==========";
         Q_EMIT status(Running, i18n("Preparing transmission from \"%1\".", name()));
         Collection targetCollection(Settings::self()->targetCollection());
-        if (!targetCollection.isValid()) {
+        if (targetCollection.isValid()) {
+            CollectionFetchJob *fetchJob = new CollectionFetchJob(targetCollection,
+                    CollectionFetchJob::Base);
+            fetchJob->start();
+            connect(fetchJob, &CollectionFetchJob::result, this, &POP3Resource::targetCollectionFetchJobFinished);
+        } else {
             // No target collection set in the config? Try requesting a default inbox
             SpecialMailCollectionsRequestJob *requestJob = new SpecialMailCollectionsRequestJob(this);
             requestJob->requestDefaultCollection(SpecialMailCollections::Inbox);
             requestJob->start();
             connect(requestJob, &SpecialMailCollectionsRequestJob::result, this, &POP3Resource::localFolderRequestJobFinished);
-        } else {
-            CollectionFetchJob *fetchJob = new CollectionFetchJob(targetCollection,
-                    CollectionFetchJob::Base);
-            fetchJob->start();
-            connect(fetchJob, &CollectionFetchJob::result, this, &POP3Resource::targetCollectionFetchJobFinished);
         }
         break;
     }
@@ -346,7 +347,7 @@ void POP3Resource::doStateStep()
         // currently on ther server, minus the ones we have already downloaded (we
         // remember which UIDs we have downloaded in the settings)
         QList<int> idsToDownload = mIdsToSizeMap.keys();
-        const QList<QString> alreadyDownloadedUIDs = Settings::self()->seenUidList();
+        const QStringList alreadyDownloadedUIDs = Settings::self()->seenUidList();
         foreach (const QString &uidOnServer, mIdsToUidsMap) {
             if (alreadyDownloadedUIDs.contains(uidOnServer)) {
                 const int idOfUIDOnServer = mUidsToIdsMap.value(uidOnServer, -1);
@@ -365,7 +366,9 @@ void POP3Resource::doStateStep()
             sizesOfMessagesToDownload.append(mIdsToSizeMap.value(id));
         }
 
-        if (!mIdsToDownload.empty()) {
+        if (mIdsToDownload.empty()) {
+            advanceState(CheckRemovingMessage);
+        } else {
             FetchJob *fetchJob = new FetchJob(mPopSession);
             fetchJob->setFetchIds(idsToDownload, sizesOfMessagesToDownload);
             connect(fetchJob, &FetchJob::result, this, &POP3Resource::fetchJobResult);
@@ -374,8 +377,6 @@ void POP3Resource::doStateStep()
                     this, SLOT(messageDownloadProgress(KJob*,KJob::Unit,qulonglong)));
 
             fetchJob->start();
-        } else {
-            advanceState(CheckRemovingMessage);
         }
     }
     break;
@@ -400,9 +401,7 @@ void POP3Resource::doStateStep()
     break;
     case SavePassword: {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state SavePassword ===================";
-        if (!mSavePassword) {
-            finish();
-        } else {
+        if (mSavePassword) {
             qCDebug(POP3RESOURCE_LOG) << "Writing password back to the wallet.";
             Q_EMIT status(Running, i18n("Saving password to the wallet."));
             mWallet = Wallet::openWallet(Wallet::NetworkWallet(), winIdForDialogs(),
@@ -412,6 +411,8 @@ void POP3Resource::doStateStep()
             } else {
                 finish();
             }
+        } else {
+            finish();
         }
         break;
     }
@@ -448,7 +449,7 @@ void POP3Resource::localFolderRequestJobFinished(KJob *job)
         return;
     }
     if (mTestLocalInbox) {
-        KMessageBox::information(Q_NULLPTR,
+        KMessageBox::information(nullptr,
                                  i18n("<qt>The folder you deleted was associated with the account "
                                       "<b>%1</b> which delivered mail into it. The folder the account "
                                       "delivers new mail into was reset to the main Inbox folder.</qt>", name()));
@@ -546,7 +547,7 @@ void POP3Resource::uidListJobResult(KJob *job)
         mUidListValid = !mIdsToUidsMap.isEmpty() || mIdsToSizeMap.isEmpty();
         if (Settings::self()->leaveOnServer() && !mUidListValid) {
             // FIXME: this needs a proper parent window
-            KMessageBox::sorry(Q_NULLPTR,
+            KMessageBox::sorry(nullptr,
                                i18n("Your POP3 server (Account: %1) does not support "
                                     "the UIDL command: this command is required to determine, in a reliable way, "
                                     "which of the mails on the server KMail has already seen before;\n"
@@ -644,7 +645,7 @@ void POP3Resource::itemCreateJobResult(KJob *job)
         return;
     }
 
-    ItemCreateJob *createJob = dynamic_cast<ItemCreateJob *>(job);
+    ItemCreateJob *createJob = qobject_cast<ItemCreateJob *>(job);
     Q_ASSERT(createJob);
 
     if (job->error()) {
@@ -690,12 +691,12 @@ int POP3Resource::idToTime(int id) const
 
     // If we don't find any mail, either we have no UID, or it is not in the seen UID
     // list. In that case, we assume that the mail is new, i.e. from now
-    return time(0);
+    return time(nullptr);
 }
 
 int POP3Resource::idOfOldestMessage(const QSet<int> &idList) const
 {
-    int timeOfOldestMessage = time(0) + 999;
+    int timeOfOldestMessage = time(nullptr) + 999;
     int idOfOldestMessage = -1;
     foreach (int id, idList) {
         const int idTime = idToTime(id);
@@ -725,7 +726,7 @@ QList<int> POP3Resource::shouldDeleteId(int downloadedId) const
             // the list of messages to keep
             if (Settings::self()->leaveOnServerDays() > 0) {
                 const int secondsPerDay = 86400;
-                time_t timeLimit = time(0) - (secondsPerDay * Settings::self()->leaveOnServerDays());
+                time_t timeLimit = time(nullptr) - (secondsPerDay * Settings::self()->leaveOnServerDays());
                 foreach (int idToDelete, idsOnServer) {
                     const int msgTime = idToTime(idToDelete);
                     if (msgTime >= timeLimit) {
@@ -764,7 +765,7 @@ QList<int> POP3Resource::shouldDeleteId(int downloadedId) const
             if (Settings::self()->leaveOnServerSize() > 0) {
                 const qint64 limitInBytes = Settings::self()->leaveOnServerSize() * (1024 * 1024);
                 qint64 sizeOnServerAfterDeletion = 0;
-                foreach (int id, mIdsToSave) {
+                for (int id : qAsConst(mIdsToSave)) {
                     sizeOnServerAfterDeletion += mIdsToSizeMap.value(id);
                 }
                 while (sizeOnServerAfterDeletion > limitInBytes) {
@@ -798,7 +799,7 @@ void POP3Resource::deleteJobResult(KJob *job)
         return;
     }
 
-    DeleteJob *finishedDeleteJob = dynamic_cast<DeleteJob *>(job);
+    DeleteJob *finishedDeleteJob = qobject_cast<DeleteJob *>(job);
     Q_ASSERT(finishedDeleteJob);
     Q_ASSERT(finishedDeleteJob == mDeleteJob);
     mDeletedIDs = finishedDeleteJob->deletedIDs();
@@ -824,7 +825,7 @@ void POP3Resource::deleteJobResult(KJob *job)
     Settings::self()->setSeenUidTimeList(timeOfSeenUids);
     Settings::self()->save();
 
-    mDeleteJob = Q_NULLPTR;
+    mDeleteJob = nullptr;
     if (!mIdsWaitingToDelete.isEmpty()) {
         mDeleteJob = new DeleteJob(mPopSession);
         mDeleteJob->setDeleteIds(mIdsWaitingToDelete);
@@ -902,7 +903,7 @@ void POP3Resource::saveSeenUIDList()
     foreach (const QString &uid, uidsOfMessagesDownloadedButNotDeleted) {
         if (!seenUIDs.contains(uid)) {
             seenUIDs.append(uid);
-            timeOfSeenUIDs.append(time(0));
+            timeOfSeenUIDs.append(time(nullptr));
         }
     }
 
@@ -947,7 +948,7 @@ void POP3Resource::cancelSync(const QString &errorMessage, bool error)
         cancelTask(errorMessage);
         qCWarning(POP3RESOURCE_LOG) << "============== ERROR DURING POP3 SYNC ==========================";
         qCWarning(POP3RESOURCE_LOG) << errorMessage;
-        KMessageBox::error(Q_NULLPTR, errorMessage);
+        KMessageBox::error(nullptr, errorMessage);
     } else {
         qCDebug(POP3RESOURCE_LOG) << "Canceled the sync, but no error.";
         cancelTask();
@@ -971,14 +972,14 @@ void POP3Resource::resetState()
     mIdsWaitingToDelete.clear();
     if (mDeleteJob) {
         mDeleteJob->deleteLater();
-        mDeleteJob = Q_NULLPTR;
+        mDeleteJob = nullptr;
     }
     mUidListValid = false;
     mIntervalCheckInProgress = false;
     mSavePassword = false;
     updateIntervalTimer();
     delete mWallet;
-    mWallet = Q_NULLPTR;
+    mWallet = nullptr;
 
     if (mPopSession) {
         // Closing the POP session means the KIO slave will get disconnected, which
@@ -986,7 +987,7 @@ void POP3Resource::resetState()
         // Delete the POP session later, otherwise the scheduler makes us crash
         mPopSession->abortCurrentJob();
         mPopSession->deleteLater();
-        mPopSession = Q_NULLPTR;
+        mPopSession = nullptr;
     }
 }
 
@@ -1035,7 +1036,7 @@ void POP3Resource::doSetOnline(bool online)
         }
         Q_EMIT status(Idle, i18n("Offline"));
         delete mWallet;
-        mWallet = Q_NULLPTR;
+        mWallet = nullptr;
         clearCachedPassword();
     }
 }
