@@ -101,14 +101,14 @@ void TomboyItemUploadJob::onRequestFinished()
     qCDebug(TOMBOYNOTESRESOURCE_LOG) << "TomboyItemUploadJob: Network request finished. No error occured";
 
     // Parse received data as JSON
-    const QJsonDocument document = QJsonDocument::fromJson(mReply->readAll(), Q_NULLPTR);
+    const QJsonDocument document = QJsonDocument::fromJson(mReply->readAll(), nullptr);
 
     const QJsonObject jo = document.object();
     const QJsonArray notes = jo[QLatin1String("notes")].toArray();
 
     // Check if server status is as expected
     bool found = false;
-    Q_FOREACH (const auto note, notes) {
+    for (const auto &note : notes) {
         found = (note.toObject()[QLatin1String("guid")].toString() == mSourceItem.remoteId());
         if (found) {
             break;
